@@ -2,7 +2,7 @@
 /*jslint browser: true */
 /*global $, jQuery, OpenLayers, window, map, updateLayer, fillSidebar,
 setUpScreen, nothingFoundPopup, reloadGraphs, reloadMapActions,
-setUpAnimationSlider */
+setUpAnimationSlider, setUpLegendTooltips */
 
 
 /*
@@ -67,11 +67,12 @@ function show_popup(data, map) {
         if (data.big) {
             size = new OpenLayers.Size(420, 610);
         }
-        popup = new OpenLayers.Popup(data.id,
-                                     new OpenLayers.LonLat(data.x, data.y),
-                                     size,
-                                     data.html,
-                                     true);
+        popup = new OpenLayers.Popup(
+            data.id,
+            new OpenLayers.LonLat(data.x, data.y),
+            size,
+            data.html + '<span class="no-hover-popups"></span>',
+            true);
         popup.panMapIfOutOfView = true;
         map.addPopup(popup);
         // make sure that when the window is closed, the object is removed as well
@@ -87,6 +88,31 @@ function show_popup(data, map) {
     }
 }
 
+function hover_popup(data, map) {
+    if (data.name !== "" &&
+        data.name !== undefined &&
+        $('.no-hover-popups').size() === 0) {
+        var size, popup;
+        $("#hover-popup").remove(); // remove existing popup, if exists
+        size = new OpenLayers.Size(300, 80);
+        popup = new OpenLayers.Popup('hover-popup',
+                                     new OpenLayers.LonLat(data.x, data.y),
+                                     size,
+                                     data.name,
+                                     false);
+        popup.autoSize = true;
+        map.addPopup(popup);
+        // make sure that when the window is closed, the object is removed as well
+        $(".olPopupCloseBox").bind("click", function () {
+            $(this).parent().parent().remove();
+        });
+        reloadGraphs();
+        // tijdelijk, hoeft niet meer als add-snippet live kan worden gebruikt
+        $(".add-snippet").snippetInteraction();
+    }
+}
+
+
 jQuery.fn.collagePopup = function () {
     var url, collage_id;
     url = $(this).parent().attr("data-url-lizard-map-collage-popup");
@@ -147,6 +173,7 @@ jQuery.fn.workspaceInteraction = function () {
         workspaceItems.droppable({
             accept: '.workspace-acceptable',
             hoverClass: 'drophover',
+            activeClass: 'dropactive',
             drop: function (event, ui) {
                 var name, adapter_class, adapter_layer_json, url;
                 // Fade out draggable item.
@@ -229,6 +256,7 @@ jQuery.fn.updateWorkspace = function () {
                 $(".map-actions").html(
                     $('.map-actions', $holder).html());
                 setUpAnimationSlider();
+                setUpLegendTooltips();
             }
         );
     });
@@ -313,6 +341,7 @@ jQuery.fn.workspaceTrashBox = function () {
         workspace_trash.droppable({
             accept: workspaceItemOrSnippet,
             hoverClass: 'drophover',
+            activeClass: 'dropactive',
             drop: function (event, ui) {
                 var object_id, url;
                 object_id = ui.draggable.attr("data-object-id");
