@@ -196,6 +196,7 @@ class WorkspaceCollage(models.Model):
                 if snippet_group.snippets.filter(
                     workspace_item=workspace_item).exists():
                     found_snippet_group = snippet_group
+                    break
 
         # (3) No existing snippet group: make one.
         if not found_snippet_group:
@@ -303,7 +304,7 @@ class WorkspaceCollageSnippetGroup(models.Model):
         snippets = self.snippets.all()
 
         # Add snippet names
-        values_table.append(['datetime'] +
+        values_table.append(['Datum + tijdstip'] +
                             [snippet.name for snippet in snippets])
 
         # Collect all data and found_dates.
