@@ -571,7 +571,7 @@ def wms(request, workspace_id):
 
 
 def search_name(request):
-    """Searche for objects near GET x,y,radius then return name,"""
+    """Search for objects near GET x,y,radius then return name,"""
     workspace_manager = WorkspaceManager(request)
     workspace_collections = workspace_manager.load_or_create()
 
@@ -592,9 +592,13 @@ def search_name(request):
         # ``found`` is a list of dicts {'distance': ..., 'timeserie': ...}.
         found.sort(key=lambda item: item['distance'])
         result = {}
-        result['name'] = found[0].name
-        print found[0].name
-        return HttpResponse(simplejson.dumps(result))
+        result['name'] = found[0]['name']
+        x, y = found[0]['google_coords']
+        result['x'] = x
+        result['y'] = y
+        return HttpResponse(json.dumps(result))
+    else:
+        return popup_json([])
 
 
 def search_coordinates(request):
@@ -675,6 +679,7 @@ def export_identifier_csv(request, workspace_item_id=None,
     """
     Uses adapter.values to get values. Then return these values in csv format.
     """
+    # Collect input.
     if workspace_item_id is None:
         workspace_item_id = request.GET.get('workspace_item_id')
     if identifier_json is None:
@@ -682,11 +687,15 @@ def export_identifier_csv(request, workspace_item_id=None,
     workspace_item = WorkspaceItem.objects.get(pk=workspace_item_id)
     identifier = parse_identifier_json(identifier_json)
     start_date, end_date = current_start_end_dates(request)
-    values = workspace_item.adapter.values(identifier, start_date, end_date)
+    adapter = workspace_item.adapter
+    values = adapter.values(identifier, start_date, end_date)
+    filename = '%s.csv' % (adapter.location(**identifier).get('name', 'export'))
 
+    # Make the csv output.
     response = HttpResponse(mimetype='text/csv')
-    response['Content-Disposition'] = 'attachment; filename=export.csv'
+    response['Content-Disposition'] = 'attachment; filename="%s"' % filename
     writer = csv.writer(response)
+    writer.writerow(['Datum + tijdstip', 'Waarde', 'Eenheid'])
     for row in values:
         writer.writerow([row['datetime'], row['value'], row['unit']])
     return response
